==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S3d25fa2cec486988552e0a9ce1a0cb49.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#ifndef Sbdf3fb01f8af462276d12d7e7e9ee85c
 
#define Sbdf3fb01f8af462276d12d7e7e9ee85c
 
#include "Sfffef868da20c3f5623f11331ac9a581.h"

#include "S749d2b576e15d77f0d14f186077e9ace.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"
 class Se812b5a98988bad1d5b8df118cb6cc7f; class S61b72eb6355a70814ce18eb4f7efa68a; class S7824a773c722026c149f24519969579a; 
class Sb1e6d560ab190f31265aad4eed6b6156 { private: bool Sb7fe9de2263da74bb3cfa87302514f81; public: Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179; Sb1e6d560ab190f31265aad4eed6b6156(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); Sb1e6d560ab190f31265aad4eed6b6156(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S18e74ae584aee591a4ca41a558933bb5); Sb1e6d560ab190f31265aad4eed6b6156(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S18e74ae584aee591a4ca41a558933bb5, S7824a773c722026c149f24519969579a 
&Sa4f359094fb25920d0a4270916aa30dc, long Sd7f5a8cd3fdf653cb0cb04f485697f85); Sb1e6d560ab190f31265aad4eed6b6156(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S18e74ae584aee591a4ca41a558933bb5, const Sb1e6d560ab190f31265aad4eed6b6156 
&S71860c77c6745379b0d44304d66b6a13); void S2e7860e5d76c562e502d72e7ad58ff43(void); Sb1e6d560ab190f31265aad4eed6b6156(const 
Sb1e6d560ab190f31265aad4eed6b6156 &Sb4b8a24be3e12d67981b918364e1d645); ~Sb1e6d560ab190f31265aad4eed6b6156(void); 
S61b72eb6355a70814ce18eb4f7efa68a *S39c2c9f6b46ec9f60db67ee1856e655e(long S198a6617dc07f3411d5c2ab23837bf26) 
const; void S608d9829dcee3f6ff37d17feeda97a08(long S198a6617dc07f3411d5c2ab23837bf26, S61b72eb6355a70814ce18eb4f7efa68a 
*S86f8ed871a2e326f1154816761110c14); void S608d9829dcee3f6ff37d17feeda97a08(long S198a6617dc07f3411d5c2ab23837bf26, 
const char *S7b0bb31f74b768daebbb6fb1a58041d9); void S7d000d12abccbd495457eb56ec963f7f(const S7824a773c722026c149f24519969579a 
&Sa4f359094fb25920d0a4270916aa30dc); void operator =(const Sb1e6d560ab190f31265aad4eed6b6156 &Sb69466b536f8ce43b6356ec1332e05a4); 
bool operator ==(const Sb1e6d560ab190f31265aad4eed6b6156 &Sb69466b536f8ce43b6356ec1332e05a4) const; 
void S13dba24862cf9128167a59100e154c8d(S1356d0666866080ee569a8007f7465e0 &Sd95679752134a2d9eb61dbd7b91c4bcc) 
const; void Sbde9f748a994fb678f513ef86b24e5c7(S1356d0666866080ee569a8007f7465e0 &Sd95679752134a2d9eb61dbd7b91c4bcc) 
const; void S4b51fc256133ba67839388dab2809dbe(Sf9590c74034599e4df344489850446f9 S15773549ac72a773120e125f74b04393) 
const; S749d2b576e15d77f0d14f186077e9ace S3afaf6e459a19d67af1f693ee4e2f502(void) const; S61b72eb6355a70814ce18eb4f7efa68a 
**Sb442f7f1021af48395bf32db5a18e8c8; long Se5927ecedb2c8688fb2646fb5bad3145; }; S1356d0666866080ee569a8007f7465e0 
&operator << (S1356d0666866080ee569a8007f7465e0 &Sd95679752134a2d9eb61dbd7b91c4bcc, const Sb1e6d560ab190f31265aad4eed6b6156 
&Sb4b8a24be3e12d67981b918364e1d645); typedef Sb1e6d560ab190f31265aad4eed6b6156 *S651bb2766f27281ac553e2f1fc5207d0; 

#endif

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/S3d25fa2cec486988552e0a9ce1a0cb49.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#ifndef Sbdf3fb01f8af462276d12d7e7e9ee85c
 
#define Sbdf3fb01f8af462276d12d7e7e9ee85c
 
#include "Sfffef868da20c3f5623f11331ac9a581.h"

#include "S749d2b576e15d77f0d14f186077e9ace.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"
 class Se812b5a98988bad1d5b8df118cb6cc7f; class S61b72eb6355a70814ce18eb4f7efa68a; class S7824a773c722026c149f24519969579a; 
class Sb1e6d560ab190f31265aad4eed6b6156 { private: bool Sb7fe9de2263da74bb3cfa87302514f81; public: Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179; Sb1e6d560ab190f31265aad4eed6b6156(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); Sb1e6d560ab190f31265aad4eed6b6156(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S18e74ae584aee591a4ca41a558933bb5); Sb1e6d560ab190f31265aad4eed6b6156(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S18e74ae584aee591a4ca41a558933bb5, S7824a773c722026c149f24519969579a 
&Sa4f359094fb25920d0a4270916aa30dc, long Sd7f5a8cd3fdf653cb0cb04f485697f85); Sb1e6d560ab190f31265aad4eed6b6156(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S18e74ae584aee591a4ca41a558933bb5, const Sb1e6d560ab190f31265aad4eed6b6156 
&S71860c77c6745379b0d44304d66b6a13); void S2e7860e5d76c562e502d72e7ad58ff43(void); Sb1e6d560ab190f31265aad4eed6b6156(const 
Sb1e6d560ab190f31265aad4eed6b6156 &Sb4b8a24be3e12d67981b918364e1d645); ~Sb1e6d560ab190f31265aad4eed6b6156(void); 
S61b72eb6355a70814ce18eb4f7efa68a *S39c2c9f6b46ec9f60db67ee1856e655e(long S198a6617dc07f3411d5c2ab23837bf26) 
const; void S608d9829dcee3f6ff37d17feeda97a08(long S198a6617dc07f3411d5c2ab23837bf26, S61b72eb6355a70814ce18eb4f7efa68a 
*S86f8ed871a2e326f1154816761110c14); void S608d9829dcee3f6ff37d17feeda97a08(long S198a6617dc07f3411d5c2ab23837bf26, 
const char *S7b0bb31f74b768daebbb6fb1a58041d9); void S7d000d12abccbd495457eb56ec963f7f(const S7824a773c722026c149f24519969579a 
&Sa4f359094fb25920d0a4270916aa30dc); void operator =(const Sb1e6d560ab190f31265aad4eed6b6156 &Sb69466b536f8ce43b6356ec1332e05a4); 
bool operator ==(const Sb1e6d560ab190f31265aad4eed6b6156 &Sb69466b536f8ce43b6356ec1332e05a4) const; 
void S13dba24862cf9128167a59100e154c8d(S1356d0666866080ee569a8007f7465e0 &Sd95679752134a2d9eb61dbd7b91c4bcc) 
const; void Sbde9f748a994fb678f513ef86b24e5c7(S1356d0666866080ee569a8007f7465e0 &Sd95679752134a2d9eb61dbd7b91c4bcc) 
const; void S4b51fc256133ba67839388dab2809dbe(Sf9590c74034599e4df344489850446f9 S15773549ac72a773120e125f74b04393) 
const; S749d2b576e15d77f0d14f186077e9ace S3afaf6e459a19d67af1f693ee4e2f502(void) const; S749d2b576e15d77f0d14f186077e9ace 
Sbce62f7aff7588e9e56595b54c07ab02(void) const; S61b72eb6355a70814ce18eb4f7efa68a **Sb442f7f1021af48395bf32db5a18e8c8; 
long Se5927ecedb2c8688fb2646fb5bad3145; }; S1356d0666866080ee569a8007f7465e0 &operator << (S1356d0666866080ee569a8007f7465e0 
&Sd95679752134a2d9eb61dbd7b91c4bcc, const Sb1e6d560ab190f31265aad4eed6b6156 &Sb4b8a24be3e12d67981b918364e1d645); 
typedef Sb1e6d560ab190f31265aad4eed6b6156 *S651bb2766f27281ac553e2f1fc5207d0; 
#endif
